"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProjectAPI = void 0;
const Endpoints_1 = require("../Endpoints");
const APIBase_1 = require("./APIBase");
class ProjectAPI extends APIBase_1.APIBase {
    constructor(apiClient, options) {
        super(apiClient, options);
    }
    /**
     * Get users that have contributed to a given project.
     * @see https://libraries.io/api#project-contributors
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Pagination options
     */
    getContributors(platform, projectName, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.Project.dependents(platform, projectName);
            const { data } = yield this.apiClient.get(endpoint, { data: options });
            return data;
        });
    }
    /**
     * Get repositories that depend on a given project.
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Pagination options
     */
    getDependendentRepositories(platform, projectName, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.Project.dependents(platform, projectName);
            const { data } = yield this.apiClient.get(endpoint, { data: options });
            return data;
        });
    }
    /**
     * Get packages that have at least one version that depends on a given project.
     * @see https://libraries.io/api#project-dependents
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Pagination options
     */
    getDependendents(platform, projectName, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.Project.dependents(platform, projectName);
            const { data } = yield this.apiClient.get(endpoint, { data: options });
            return data;
        });
    }
    /**
     * Get information about a package and it's versions.
     * @see https://libraries.io/api#project
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    getProject(platform, projectName) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.Project.project(platform, projectName);
            const { data } = yield this.apiClient.get(endpoint);
            return data;
        });
    }
    /**
     * Get a list of dependencies for a version of a project, pass `latest` as version to get dependency info for the latest available version
     * @see https://libraries.io/api#project-dependencies
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param projectVersion
     */
    getProjectWithDependencies(platform, projectName, projectVersion) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.Project.dependencies(platform, projectName, projectVersion);
            const { data } = yield this.apiClient.get(endpoint);
            return data;
        });
    }
    /**
     * Get breakdown of SourceRank score for a given project.
     * @see https://libraries.io/api#project-sourcerank
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    getSourceRank(platform, projectName) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.Project.sourceRank(platform, projectName);
            const { data } = yield this.apiClient.get(endpoint);
            return data;
        });
    }
    /**
     * Get breakdown of version usage for a given project.
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    getUsage(platform, projectName) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.Project.sourceRank(platform, projectName);
            const { data } = yield this.apiClient.get(endpoint);
            return data;
        });
    }
    /**
     * Search for projects.
     * @see https://libraries.io/api#project-search
     * @param query The search query
     * @param options Sorting, filter and pagination options
     */
    search(query, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const endpoint = Endpoints_1.Endpoint.Project.search();
            // eslint-disable-next-line id-length
            const { data } = yield this.apiClient.get(endpoint, { data: Object.assign(Object.assign({}, options), { q: query }) });
            return data;
        });
    }
}
exports.ProjectAPI = ProjectAPI;
//# sourceMappingURL=ProjectAPI.js.map